Methods
===================

Generic methods
---------------------------------

.. automodule:: nes.methods.cell_measures
   :members:
   :undoc-members:
   :show-inheritance:

Horizontal interpolation
--------------------------------------------

.. automodule:: nes.methods.horizontal_interpolation
   :members:
   :undoc-members:
   :show-inheritance:

Spatial join
--------------------------------

.. automodule:: nes.methods.spatial_join
   :members:
   :undoc-members:
   :show-inheritance:

Vertical interpolation
------------------------------------------

.. automodule:: nes.methods.vertical_interpolation
   :members:
   :undoc-members:
   :show-inheritance:
